GoPredeclaredIdentifier

Enum GoPredeclaredIdentifier 

pub enum GoPredeclaredIdentifier {
Show 44 variants Any, Bool, Byte, Comparable, Complex64, Complex128, Error, Float32, Float64, Int, Int8, Int16, Int32, Int64, Rune, String, Uint, Uint8, Uint16, Uint32, Uint64, Uintptr, True, False, Iota, Nil, Append, Cap, Clear, Close, Complex, Copy, Delete, Imag, Len, Make, Max, Min, New, Panic, Print, Println, Real, Recover,
}
Common Go predeclared identifiers.

Variants



Any



Bool



Byte



Comparable



Complex64



Complex128



Error



Float32



Float64



Int



Int8



Int16



Int32



Int64



Rune



String



Uint



Uint8



Uint16



Uint32



Uint64



Uintptr



True



False



Iota



Nil



Append



Cap



Clear



Close



Complex



Copy



Delete



Imag



Len



Make



Max



Min



New



Panic



Print



Println



Real



Recover

Implementations

Source

impl GoPredeclaredIdentifier

pub const fn as_str(self) -> &'static str

Returns the identifier label as it appears in Go source.